/* hdecompress.c Return image from compressed image file created by hcompress
 *
 * Programmer: R. White		Date: 20 May 1991
 *
 * Modified by R. White, 18 June 1992, to use better VMS I/O routines.
 *
 * Modified by J. Doggett, 7 December 1993
 *         to add qclose prototype
 */

/******************************************************************************
* Copyright (c) 1993, 1994, Association of Universities for Research in       *
* Astronomy, Inc.  All Rights Reserved.                                       *
* Produced under National Aeronautics and Space Administration grant          *
* NAG W-2166.                                                                 *
******************************************************************************/

#include <stdio.h>
#include "qfile.h"

/*
 * if verbose is set to non-zero value, some information about
 * compression efficiency is printed on stderr
 */
int verbose;

extern void decode();
extern void undigitize();
extern void hinv();

extern void qclose();

extern void
hdecompress(a,nx,ny,filename)
int  **a;					/* (*a)[nx][ny] is the image array				*/
int  *nx;
int  *ny;					/* Note that ny is the fast-varying dimension	*/
char *filename;				/* Name of input file							*/
{
QFILE *infile;
int scale;

	/*
	 * open input file, 512 byte records, no carriage control
	 */
	infile = qopen(filename,512,0);
	decode(infile,a,nx,ny,&scale);		/* Read from infile and decode		*/
										/* Returns address & size			*/
	qclose(infile);						/* Close infile						*/
	undigitize(*a,*nx,*ny,scale);		/* Un-Digitize						*/
	hinv(*a,*nx,*ny);					/* Inverse H-transform				*/
	if (verbose) {
		fprintf(stderr, "Image size (%d,%d)  Scale factor %d\n",
			*ny,*nx,scale);
	}
}
